@@ -23,6 +23,19 @@ QTYPES = ('appengine', 'aws')#, 'google')
 
 QURL = 'https://sqs.us-east-1.amazonaws.com/098703261575/wms-test-pull-queue'
 
+def test_task_creation():
+  task = MockTask(this="is", a=[1, 4, 2], simple={"test": "to", "check": 4},
+               serialization=('i', 's', 's', 'u', 'e', 's'), with_kwargs=None)
+  task_str = task.serialize()
+  task_deserialized = MockTask.deserialize(task_str)
+
+  assert task_deserialized._args == {
+      "this": "is", "a": [1, 4, 2],
+      "simple": {"test": "to", "check": 4},
+      "serialization": ["i", "s", "s", "u", "e", "s"],
+      "with_kwargs": None
+  }
+
 def test_get():
   global QUEUE_NAME
 
@@ -102,5 +115,5 @@ def test_local_taskqueue():
   with LocalTaskQueue(parallel=True, progress=False) as tq:
     for i in range(20000):
       tq.insert(
-        MockTask(i)
+        MockTask(arg=i)
       )
\ No newline at end of file
